@@ -31,19 +31,28 @@ class SubscriptionAdmin(admin.ModelAdmin):
                     'customer_id', 'subscription_id', 'is_active')
     list_filter = ('is_active', 'created_at')
 
+    def stripe_plan(self, obj=None):
+        if obj:
+            return obj.plan.title
+
+    stripe_plan.short_description = 'Plan'
+
     def get_fieldsets(self, request, obj=None):
         fieldsets = [
             (None, {
                 "fields": ['is_active', 'created_at', 'updated_at']
             }),
             ('Stripe', {
-                "fields": ('plan', 'customer_id', 'subscription_id')
+                "fields": ['customer_id', 'subscription_id']
             }),
         ]
 
         if request.user.is_superuser:
             fieldsets[0][1]['fields'].insert(0, 'user')
+            fieldsets[1][1]['fields'].insert(0, 'plan')
             fieldsets.append(('Quiz', {"fields": ('quiz',)}))
+        else:
+            fieldsets[1][1]['fields'].insert(0, 'stripe_plan')
 
         return fieldsets
 
