@@ -122,7 +122,7 @@ def cancel_subscription_confirm(request, token):
     template = cfg.get_template(request.get_host(), 'cancel-success')
     context = {
         'is_ok': utils.cancel_subscription(obj) if obj.is_active else True,
-        'host': obj.site.domain
+        'host': request.get_host()
     }
 
     return render(request, template, context)
